==> aws-cdk-lib-2.210.0-sources.jar: software/amazon/awscdk/services/mediapackagev2/CfnOriginEndpointPolicyProps.java <==
package software.amazon.awscdk.services.mediapackagev2;

/**
 * Properties for defining a <code>CfnOriginEndpointPolicy</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.mediapackagev2.*;
 * Object policy;
 * CfnOriginEndpointPolicyProps cfnOriginEndpointPolicyProps = CfnOriginEndpointPolicyProps.builder()
 *         .channelGroupName("channelGroupName")
 *         .channelName("channelName")
 *         .originEndpointName("originEndpointName")
 *         .policy(policy)
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.112.0 (build de1bc80)", date = "2025-08-06T18:14:41.222Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_mediapackagev2.CfnOriginEndpointPolicyProps")
@software.amazon.jsii.Jsii.Proxy(CfnOriginEndpointPolicyProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnOriginEndpointPolicyProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the channel group associated with the origin endpoint policy.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-channelgroupname">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-channelgroupname</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getChannelGroupName();

    /**
     * The channel name associated with the origin endpoint policy.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-channelname">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-channelname</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getChannelName();

    /**
     * The name of the origin endpoint associated with the origin endpoint policy.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-originendpointname">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-originendpointname</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getOriginEndpointName();

    /**
     * The policy associated with the origin endpoint.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-policy">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-policy</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getPolicy();

    /**
     * @return a {@link Builder} of {@link CfnOriginEndpointPolicyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnOriginEndpointPolicyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnOriginEndpointPolicyProps> {
        java.lang.String channelGroupName;
        java.lang.String channelName;
        java.lang.String originEndpointName;
        java.lang.Object policy;

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getChannelGroupName}
         * @param channelGroupName The name of the channel group associated with the origin endpoint policy. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder channelGroupName(java.lang.String channelGroupName) {
            this.channelGroupName = channelGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getChannelName}
         * @param channelName The channel name associated with the origin endpoint policy. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder channelName(java.lang.String channelName) {
            this.channelName = channelName;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getOriginEndpointName}
         * @param originEndpointName The name of the origin endpoint associated with the origin endpoint policy. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originEndpointName(java.lang.String originEndpointName) {
            this.originEndpointName = originEndpointName;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getPolicy}
         * @param policy The policy associated with the origin endpoint. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder policy(java.lang.Object policy) {
            this.policy = policy;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnOriginEndpointPolicyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnOriginEndpointPolicyProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnOriginEndpointPolicyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnOriginEndpointPolicyProps {
        private final java.lang.String channelGroupName;
        private final java.lang.String channelName;
        private final java.lang.String originEndpointName;
        private final java.lang.Object policy;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.channelGroupName = software.amazon.jsii.Kernel.get(this, "channelGroupName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.channelName = software.amazon.jsii.Kernel.get(this, "channelName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.originEndpointName = software.amazon.jsii.Kernel.get(this, "originEndpointName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.policy = software.amazon.jsii.Kernel.get(this, "policy", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.channelGroupName = java.util.Objects.requireNonNull(builder.channelGroupName, "channelGroupName is required");
            this.channelName = java.util.Objects.requireNonNull(builder.channelName, "channelName is required");
            this.originEndpointName = java.util.Objects.requireNonNull(builder.originEndpointName, "originEndpointName is required");
            this.policy = java.util.Objects.requireNonNull(builder.policy, "policy is required");
        }

        @Override
        public final java.lang.String getChannelGroupName() {
            return this.channelGroupName;
        }

        @Override
        public final java.lang.String getChannelName() {
            return this.channelName;
        }

        @Override
        public final java.lang.String getOriginEndpointName() {
            return this.originEndpointName;
        }

        @Override
        public final java.lang.Object getPolicy() {
            return this.policy;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("channelGroupName", om.valueToTree(this.getChannelGroupName()));
            data.set("channelName", om.valueToTree(this.getChannelName()));
            data.set("originEndpointName", om.valueToTree(this.getOriginEndpointName()));
            data.set("policy", om.valueToTree(this.getPolicy()));

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_mediapackagev2.CfnOriginEndpointPolicyProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnOriginEndpointPolicyProps.Jsii$Proxy that = (CfnOriginEndpointPolicyProps.Jsii$Proxy) o;

            if (!channelGroupName.equals(that.channelGroupName)) return false;
            if (!channelName.equals(that.channelName)) return false;
            if (!originEndpointName.equals(that.originEndpointName)) return false;
            return this.policy.equals(that.policy);
        }

        @Override
        public final int hashCode() {
            int result = this.channelGroupName.hashCode();
            result = 31 * result + (this.channelName.hashCode());
            result = 31 * result + (this.originEndpointName.hashCode());
            result = 31 * result + (this.policy.hashCode());
            return result;
        }
    }
}

==> aws-cdk-lib-2.211.0-sources.jar: software/amazon/awscdk/services/mediapackagev2/CfnOriginEndpointPolicyProps.java <==
package software.amazon.awscdk.services.mediapackagev2;

/**
 * Properties for defining a <code>CfnOriginEndpointPolicy</code>.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.mediapackagev2.*;
 * Object policy;
 * CfnOriginEndpointPolicyProps cfnOriginEndpointPolicyProps = CfnOriginEndpointPolicyProps.builder()
 *         .channelGroupName("channelGroupName")
 *         .channelName("channelName")
 *         .originEndpointName("originEndpointName")
 *         .policy(policy)
 *         // the properties below are optional
 *         .cdnAuthConfiguration(CdnAuthConfigurationProperty.builder()
 *                 .cdnIdentifierSecretArns(List.of("cdnIdentifierSecretArns"))
 *                 .secretsRoleArn("secretsRoleArn")
 *                 .build())
 *         .build();
 * </pre></blockquote>
 * <p>
 * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html</a>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.113.0 (build fc68b25)", date = "2025-08-12T14:44:19.574Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_mediapackagev2.CfnOriginEndpointPolicyProps")
@software.amazon.jsii.Jsii.Proxy(CfnOriginEndpointPolicyProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnOriginEndpointPolicyProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * The name of the channel group associated with the origin endpoint policy.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-channelgroupname">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-channelgroupname</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getChannelGroupName();

    /**
     * The channel name associated with the origin endpoint policy.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-channelname">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-channelname</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getChannelName();

    /**
     * The name of the origin endpoint associated with the origin endpoint policy.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-originendpointname">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-originendpointname</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getOriginEndpointName();

    /**
     * The policy associated with the origin endpoint.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-policy">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-policy</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Object getPolicy();

    /**
     * The settings to enable CDN authorization headers in MediaPackage.
     * <p>
     * @see <a href="http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-cdnauthconfiguration">http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackagev2-originendpointpolicy.html#cfn-mediapackagev2-originendpointpolicy-cdnauthconfiguration</a>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getCdnAuthConfiguration() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link CfnOriginEndpointPolicyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link CfnOriginEndpointPolicyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<CfnOriginEndpointPolicyProps> {
        java.lang.String channelGroupName;
        java.lang.String channelName;
        java.lang.String originEndpointName;
        java.lang.Object policy;
        java.lang.Object cdnAuthConfiguration;

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getChannelGroupName}
         * @param channelGroupName The name of the channel group associated with the origin endpoint policy. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder channelGroupName(java.lang.String channelGroupName) {
            this.channelGroupName = channelGroupName;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getChannelName}
         * @param channelName The channel name associated with the origin endpoint policy. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder channelName(java.lang.String channelName) {
            this.channelName = channelName;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getOriginEndpointName}
         * @param originEndpointName The name of the origin endpoint associated with the origin endpoint policy. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder originEndpointName(java.lang.String originEndpointName) {
            this.originEndpointName = originEndpointName;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getPolicy}
         * @param policy The policy associated with the origin endpoint. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder policy(java.lang.Object policy) {
            this.policy = policy;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getCdnAuthConfiguration}
         * @param cdnAuthConfiguration The settings to enable CDN authorization headers in MediaPackage.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cdnAuthConfiguration(software.amazon.awscdk.IResolvable cdnAuthConfiguration) {
            this.cdnAuthConfiguration = cdnAuthConfiguration;
            return this;
        }

        /**
         * Sets the value of {@link CfnOriginEndpointPolicyProps#getCdnAuthConfiguration}
         * @param cdnAuthConfiguration The settings to enable CDN authorization headers in MediaPackage.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cdnAuthConfiguration(software.amazon.awscdk.services.mediapackagev2.CfnOriginEndpointPolicy.CdnAuthConfigurationProperty cdnAuthConfiguration) {
            this.cdnAuthConfiguration = cdnAuthConfiguration;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnOriginEndpointPolicyProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public CfnOriginEndpointPolicyProps build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link CfnOriginEndpointPolicyProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements CfnOriginEndpointPolicyProps {
        private final java.lang.String channelGroupName;
        private final java.lang.String channelName;
        private final java.lang.String originEndpointName;
        private final java.lang.Object policy;
        private final java.lang.Object cdnAuthConfiguration;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.channelGroupName = software.amazon.jsii.Kernel.get(this, "channelGroupName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.channelName = software.amazon.jsii.Kernel.get(this, "channelName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.originEndpointName = software.amazon.jsii.Kernel.get(this, "originEndpointName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.policy = software.amazon.jsii.Kernel.get(this, "policy", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.cdnAuthConfiguration = software.amazon.jsii.Kernel.get(this, "cdnAuthConfiguration", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.channelGroupName = java.util.Objects.requireNonNull(builder.channelGroupName, "channelGroupName is required");
            this.channelName = java.util.Objects.requireNonNull(builder.channelName, "channelName is required");
            this.originEndpointName = java.util.Objects.requireNonNull(builder.originEndpointName, "originEndpointName is required");
            this.policy = java.util.Objects.requireNonNull(builder.policy, "policy is required");
            this.cdnAuthConfiguration = builder.cdnAuthConfiguration;
        }

        @Override
        public final java.lang.String getChannelGroupName() {
            return this.channelGroupName;
        }

        @Override
        public final java.lang.String getChannelName() {
            return this.channelName;
        }

        @Override
        public final java.lang.String getOriginEndpointName() {
            return this.originEndpointName;
        }

        @Override
        public final java.lang.Object getPolicy() {
            return this.policy;
        }

        @Override
        public final java.lang.Object getCdnAuthConfiguration() {
            return this.cdnAuthConfiguration;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("channelGroupName", om.valueToTree(this.getChannelGroupName()));
            data.set("channelName", om.valueToTree(this.getChannelName()));
            data.set("originEndpointName", om.valueToTree(this.getOriginEndpointName()));
            data.set("policy", om.valueToTree(this.getPolicy()));
            if (this.getCdnAuthConfiguration() != null) {
                data.set("cdnAuthConfiguration", om.valueToTree(this.getCdnAuthConfiguration()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("aws-cdk-lib.aws_mediapackagev2.CfnOriginEndpointPolicyProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            CfnOriginEndpointPolicyProps.Jsii$Proxy that = (CfnOriginEndpointPolicyProps.Jsii$Proxy) o;

            if (!channelGroupName.equals(that.channelGroupName)) return false;
            if (!channelName.equals(that.channelName)) return false;
            if (!originEndpointName.equals(that.originEndpointName)) return false;
            if (!policy.equals(that.policy)) return false;
            return this.cdnAuthConfiguration != null ? this.cdnAuthConfiguration.equals(that.cdnAuthConfiguration) : that.cdnAuthConfiguration == null;
        }

        @Override
        public final int hashCode() {
            int result = this.channelGroupName.hashCode();
            result = 31 * result + (this.channelName.hashCode());
            result = 31 * result + (this.originEndpointName.hashCode());
            result = 31 * result + (this.policy.hashCode());
            result = 31 * result + (this.cdnAuthConfiguration != null ? this.cdnAuthConfiguration.hashCode() : 0);
            return result;
        }
    }
}
